@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2002 Zope Corporation and Contributors.
+# Copyright (c) 2002 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,8 +12,6 @@
 #
 ##############################################################################
 """Locale and LocaleProvider Implementation.
-
-$Id: __init__.py 97333 2009-02-27 09:11:16Z nadako $
 """
 __docformat__ = 'restructuredtext'
 
@@ -21,7 +19,7 @@ import os
 from datetime import datetime, date
 from time import strptime
 
-from zope.interface import implements
+from zope.interface import implementer
 from zope.i18n.interfaces.locales import ILocale
 from zope.i18n.interfaces.locales import ILocaleDisplayNames, ILocaleDates
 from zope.i18n.interfaces.locales import ILocaleVersion, ILocaleIdentity
@@ -34,6 +32,7 @@ from zope.i18n.format import NumberFormat, DateTimeFormat
 from zope.i18n.locales.inheritance import \
      AttributeInheritance, InheritingDictionary, NoParentException
 from zope.i18n.locales.provider import LocaleProvider, LoadLocaleError
+from .._compat import _u
 
 # Setup the locale directory
 from zope import i18n
@@ -75,6 +74,7 @@ calendarAliases = {'islamic': ('arabic',),
                    'islamic-civil': ('civil-arabic',),
                    'buddhist': ('thai-buddhist', )}
 
+@implementer(ILocaleIdentity)
 class LocaleIdentity(object):
     """Represents a unique identification of the locale
 
@@ -102,7 +102,6 @@ class LocaleIdentity(object):
       >>> id
       <LocaleIdentity (en, None, US, POSIX)>
     """
-    implements(ILocaleIdentity)
 
     def __init__(self, language=None, script=None, territory=None, variant=None):
         """Initialize object."""
@@ -118,6 +117,7 @@ class LocaleIdentity(object):
             self.language, self.script, self.territory, self.variant)
 
 
+@implementer(ILocaleVersion)
 class LocaleVersion(object):
     """Represents a particular version of a locale
 
@@ -125,24 +125,23 @@ class LocaleVersion(object):
 
     Examples::
 
-      >>> cmp(LocaleVersion('1.0', datetime(2004, 1, 1), 'no notes'),
+      >>> (LocaleVersion('1.0', datetime(2004, 1, 1), 'no notes') ==
       ...     LocaleVersion('1.0', datetime(2004, 1, 1), 'no notes again'))
-      0
+      True
 
-      >>> cmp(LocaleVersion('1.0', datetime(2004, 1, 1), 'no notes'),
+      >>> (LocaleVersion('1.0', datetime(2004, 1, 1), 'no notes') <
       ...     LocaleVersion('1.0', datetime(2004, 1, 2), 'no notes again'))
-      -1
+      True
 
-      >>> cmp(LocaleVersion('1.0', datetime(2004, 1, 1), 'no notes'),
+      >>> (LocaleVersion('1.0', datetime(2004, 1, 1), 'no notes') <
       ...     LocaleVersion('0.9', datetime(2004, 1, 2), 'no notes again'))
-      -1
+      True
 
-      >>> cmp(LocaleVersion('1.0', datetime(2004, 1, 1), 'no notes'),
+      >>> (LocaleVersion('1.0', datetime(2004, 1, 1), 'no notes') >
       ...     LocaleVersion('0.9', datetime(2004, 1, 1), 'no notes again'))
-      1
+      True
 
     """
-    implements(ILocaleVersion)
 
     def __init__(self, number, generationDate, notes):
         """Initialize object."""
@@ -151,12 +150,15 @@ class LocaleVersion(object):
         self.generationDate = generationDate
         self.notes = notes
 
-    def __cmp__(self, other):
-        "See zope.i18n.interfaces.ILocaleVersion"
-        return cmp((self.generationDate, self.number),
-                   (other.generationDate, other.number))
+    def __lt__(self, other):
+        return ((self.generationDate, self.number) <
+                (other.generationDate, other.number))
 
+    def __eq__(self, other):
+        return ((self.generationDate, self.number) ==
+                (other.generationDate, other.number))
 
+@implementer(ILocaleDisplayNames)
 class LocaleDisplayNames(AttributeInheritance):
     """Locale display names with inheritable data.
 
@@ -180,9 +182,9 @@ class LocaleDisplayNames(AttributeInheritance):
       >>> locale.displayNames.keys
       ['fu', 'bahr']
     """
-    implements(ILocaleDisplayNames)
 
 
+@implementer(ILocaleTimeZone)
 class LocaleTimeZone(object):
     """Specifies one of the timezones of a specific locale.
 
@@ -201,7 +203,6 @@ class LocaleTimeZone(object):
       >>> tz.cities
       ['Berlin']
     """
-    implements(ILocaleTimeZone)
 
     def __init__(self, type):
         """Initialize the object."""
@@ -210,6 +211,7 @@ class LocaleTimeZone(object):
         self.names = {}
 
 
+@implementer(ILocaleFormat)
 class LocaleFormat(object):
     """Specifies one of the format of a specific format length.
 
@@ -218,20 +220,19 @@ class LocaleFormat(object):
     itself is often not useful, since other calendar data is required to use
     the specified pattern for formatting and parsing.
     """
-    implements(ILocaleFormat)
 
     def __init__(self, type=None):
         """Initialize the object."""
         self.type = type
-        self.displayName = u''
-        self.pattern = u''
+        self.displayName = _u("")
+        self.pattern = _u("")
 
 
+@implementer(ILocaleFormatLength)
 class LocaleFormatLength(AttributeInheritance):
     """Specifies one of the format lengths of a specific quantity, like
     numbers, dates, times and datetimes."""
 
-    implements(ILocaleFormatLength)
 
     def __init__(self, type=None):
         """Initialize the object."""
@@ -239,26 +240,25 @@ class LocaleFormatLength(AttributeInheritance):
         self.default = None
 
 
+@implementer(ILocaleMonthContext)
 class LocaleMonthContext(AttributeInheritance):
 
-    implements(ILocaleMonthContext)
-
     def __init__(self, type=None):
         """Initialize the object."""
         self.type = type
-        self.default = u'wide'
+        self.default = _u("wide")
 
 
+@implementer(ILocaleDayContext)
 class LocaleDayContext(AttributeInheritance):
 
-    implements(ILocaleDayContext)
-
     def __init__(self, type=None):
         """Initialize the object."""
         self.type = type
-        self.default = u'wide'
+        self.default = _u("wide")
 
 
+@implementer(ILocaleCalendar)
 class LocaleCalendar(AttributeInheritance):
     """Represents locale data for a calendar, like 'gregorian'.
 
@@ -280,50 +280,49 @@ class LocaleCalendar(AttributeInheritance):
       >>> locale.calendar = LocaleCalendar('gregorian')
 
       >>> root.calendar.months = InheritingDictionary(
-      ...     {1: (u'January', u'Jan'), 2: (u'February', u'Feb')})
+      ...     {1: (_u("January"), _u("Jan")), 2: (_u("February"), _u("Feb"))})
       >>> locale.calendar.months = InheritingDictionary(
-      ...     {2: (u'Februar', u'Feb'), 3: (u'Maerz', u'Mrz')})
+      ...     {2: (_u("Februar"), _u("Feb")), 3: (_u("Maerz"), _u("Mrz"))})
       >>> locale.calendar.getMonthNames()[:4]
       [u'January', u'Februar', u'Maerz', None]
-      >>> locale.calendar.getMonthTypeFromName(u'January')
+      >>> locale.calendar.getMonthTypeFromName(_u("January"))
       1
-      >>> locale.calendar.getMonthTypeFromName(u'Februar')
+      >>> locale.calendar.getMonthTypeFromName(_u("Februar"))
       2
       >>> locale.calendar.getMonthAbbreviations()[:4]
       [u'Jan', u'Feb', u'Mrz', None]
-      >>> locale.calendar.getMonthTypeFromAbbreviation(u'Jan')
+      >>> locale.calendar.getMonthTypeFromAbbreviation(_u("Jan"))
       1
-      >>> locale.calendar.getMonthTypeFromAbbreviation(u'Mrz')
+      >>> locale.calendar.getMonthTypeFromAbbreviation(_u("Mrz"))
       3
 
       >>> root.calendar.days = InheritingDictionary(
-      ...     {1: (u'Monday', u'Mon'), 2: (u'Tuesday', u'Tue')})
+      ...     {1: (_u("Monday"), _u("Mon")), 2: (_u("Tuesday"), _u("Tue"))})
       >>> locale.calendar.days = InheritingDictionary(
-      ...     {2: (u'Dienstag', u'Die'), 3: (u'Mittwoch', u'Mit')})
+      ...     {2: (_u("Dienstag"), _u("Die")), 3: (_u("Mittwoch"), _u("Mit"))})
       >>> locale.calendar.getDayNames()[:4]
       [u'Monday', u'Dienstag', u'Mittwoch', None]
-      >>> locale.calendar.getDayTypeFromName(u'Monday')
+      >>> locale.calendar.getDayTypeFromName(_u("Monday"))
       1
-      >>> locale.calendar.getDayTypeFromName(u'Dienstag')
+      >>> locale.calendar.getDayTypeFromName(_u("Dienstag"))
       2
       >>> locale.calendar.getDayAbbreviations()[:4]
       [u'Mon', u'Die', u'Mit', None]
-      >>> locale.calendar.getDayTypeFromAbbreviation(u'Mon')
+      >>> locale.calendar.getDayTypeFromAbbreviation(_u("Mon"))
       1
-      >>> locale.calendar.getDayTypeFromAbbreviation(u'Die')
+      >>> locale.calendar.getDayTypeFromAbbreviation(_u("Die"))
       2
 
     Let's test the direct attribute access as well.
 
-      >>> root.am = u'AM'
-      >>> root.pm = u'PM'
-      >>> locale.pm = u'nachm.'
+      >>> root.am = _u("AM")
+      >>> root.pm = _u("PM")
+      >>> locale.pm = _u("nachm.")
       >>> locale.pm
       u'nachm.'
       >>> locale.am
       u'AM'
     """
-    implements(ILocaleCalendar)
 
     def __init__(self, type):
         """Initialize the object."""
@@ -381,6 +380,7 @@ class LocaleCalendar(AttributeInheritance):
         return self.days[dayMapping[self.week['firstDay']]][0]
 
 
+@implementer(ILocaleDates)
 class LocaleDates(AttributeInheritance):
     """Simple ILocaleDates implementation that can inherit data from other
     locales.
@@ -404,35 +404,35 @@ class LocaleDates(AttributeInheritance):
 
       >>> fulllength = LocaleFormatLength()
       >>> format = LocaleFormat()
-      >>> format.pattern = u'EEEE, d. MMMM yyyy'
+      >>> format.pattern = _u("EEEE, d. MMMM yyyy")
       >>> fulllength.formats = {None: format}
 
       >>> mediumlength = LocaleFormatLength()
       >>> format = LocaleFormat()
-      >>> format.pattern = u'dd.MM.yyyy'
+      >>> format.pattern = _u("dd.MM.yyyy")
       >>> mediumlength.formats = {None: format}
 
       >>> cal.dateFormats = {'full': fulllength, 'medium': mediumlength}
       >>> cal.defaultDateFormat = 'medium'
 
       >>> formatter = dates.getFormatter('date')
-      >>> formatter.format(date(2004, 02, 04))
+      >>> formatter.format(date(2004, 2, 4))
       u'04.02.2004'
 
       >>> formatter = dates.getFormatter('date', length='full')
-      >>> formatter.format(date(2004, 02, 04))
+      >>> formatter.format(date(2004, 2, 4))
       u'Mittwoch, 4. Februar 2004'
 
     Let's also test the time formatter::
 
       >>> fulllength = LocaleFormatLength()
       >>> format = LocaleFormat()
-      >>> format.pattern = u"H:mm' Uhr 'z"
+      >>> format.pattern = _u("H:mm' Uhr 'z")
       >>> fulllength.formats = {None: format}
 
       >>> mediumlength = LocaleFormatLength()
       >>> format = LocaleFormat()
-      >>> format.pattern = u'HH:mm:ss'
+      >>> format.pattern = _u("HH:mm:ss")
       >>> mediumlength.formats = {None: format}
 
       >>> cal.timeFormats = {'full': fulllength, 'medium': mediumlength}
@@ -451,16 +451,16 @@ class LocaleDates(AttributeInheritance):
 
       >>> length = LocaleFormatLength()
       >>> format = LocaleFormat()
-      >>> format.pattern = u'{1} {0}'
+      >>> format.pattern = _u("{1} {0}")
       >>> length.formats = {None: format}
       >>> cal.dateTimeFormats = {None: length}
 
       >>> formatter = dates.getFormatter('dateTime')
-      >>> formatter.format(datetime(2004, 02, 04, 12, 15, 00))
+      >>> formatter.format(datetime(2004, 2, 4, 12, 15, 00))
       u'04.02.2004 12:15:00'
 
       >>> formatter = dates.getFormatter('dateTime', length='full')
-      >>> formatter.format(datetime(2004, 02, 04, 12, 15, 00))
+      >>> formatter.format(datetime(2004, 2, 4, 12, 15, 00))
       u'Mittwoch, 4. Februar 2004 12:15 Uhr +000'
 
     Finally, we'll test some invalid input::
@@ -478,18 +478,17 @@ class LocaleDates(AttributeInheritance):
       ValueError: Invalid calendar: irish-catholic
 
     """
-    implements(ILocaleDates)
 
     def getFormatter(self, category, length=None, name=None,
-                     calendar=u'gregorian'):
+                     calendar=_u("gregorian")):
         """See zope.i18n.interfaces.locales.ILocaleDates"""
-        if category not in (u'date', u'time', u'dateTime'):
+        if category not in (_u("date"), _u("time"), _u("dateTime")):
             raise ValueError('Invalid category: %s' % category)
-        if calendar not in (u'gregorian', u'arabic', u'chinese',
-                            u'civil-arabic', u'hebrew', u'japanese',
-                            u'thai-buddhist'):
+        if calendar not in (_u("gregorian"), _u("arabic"), _u("chinese"),
+                            _u("civil-arabic"), _u("hebrew"), _u("japanese"),
+                            _u("thai-buddhist")):
             raise ValueError('Invalid calendar: %s' % calendar)
-        if length not in (u'short', u'medium', u'long', u'full', None):
+        if length not in (_u("short"), _u("medium"), _u("long"), _u("full"), None):
             raise ValueError('Invalid format length: %s' % length)
 
         cal = self.calendars[calendar]
@@ -499,7 +498,7 @@ class LocaleDates(AttributeInheritance):
             length = getattr(
                 cal,
                 'default'+category[0].upper()+category[1:]+'Format',
-                formats.keys()[0])
+                list(formats.keys())[0])
 
         # 'datetime' is always a bit special; we often do not have a length
         # specification, but we need it for looking up the date and time
@@ -526,10 +525,10 @@ class LocaleDates(AttributeInheritance):
         return DateTimeFormat(pattern, cal)
 
 
+@implementer(ILocaleCurrency)
 class LocaleCurrency(object):
     """Simple implementation of ILocaleCurrency without inheritance support,
     since it is not needed for a single currency."""
-    implements(ILocaleCurrency)
 
     def __init__(self, type):
         """Initialize object."""
@@ -539,6 +538,7 @@ class LocaleCurrency(object):
         self.displayName = None
 
 
+@implementer(ILocaleNumbers)
 class LocaleNumbers(AttributeInheritance):
     """Implementation of ILocaleCurrency including inheritance support.
 
@@ -556,7 +556,7 @@ class LocaleNumbers(AttributeInheritance):
 
       >>> length = LocaleFormatLength()
       >>> format = LocaleFormat()
-      >>> format.pattern = u'#,##0.###;-#,##0.###'
+      >>> format.pattern = _u("#,##0.###;-#,##0.###")
       >>> length.formats = {None: format}
       >>> numbers.decimalFormats = {None: length}
       >>> formatter = numbers.getFormatter('decimal')
@@ -571,11 +571,11 @@ class LocaleNumbers(AttributeInheritance):
 
       >>> longlength = LocaleFormatLength('long')
       >>> format = LocaleFormat()
-      >>> format.pattern = u'0.000###E+00'
+      >>> format.pattern = _u("0.000###E+00")
       >>> longlength.formats = {None: format}
       >>> mediumlength = LocaleFormatLength('long')
       >>> format = LocaleFormat()
-      >>> format.pattern = u'0.00##E+00'
+      >>> format.pattern = _u("0.00##E+00")
       >>> mediumlength.formats = {None: format}
       >>> numbers.scientificFormats = {'long': longlength,
       ...                              'medium': mediumlength}
@@ -592,9 +592,9 @@ class LocaleNumbers(AttributeInheritance):
 
       >>> longlength = LocaleFormatLength('long')
       >>> fooformat = LocaleFormat()
-      >>> fooformat.pattern = u'0.##0%'
+      >>> fooformat.pattern = _u("0.##0%")
       >>> barformat = LocaleFormat()
-      >>> barformat.pattern = u'0%'
+      >>> barformat.pattern = _u("0%")
       >>> longlength.formats = {None: fooformat, 'bar': barformat}
       >>> numbers.percentFormats = {'long': longlength}
       >>> numbers.defaultPercentFormat = 'long'
@@ -613,19 +613,18 @@ class LocaleNumbers(AttributeInheritance):
       u'123%'
 
     """
-    implements(ILocaleNumbers)
 
     def getFormatter(self, category, length=None, name=None):
         """See zope.i18n.interfaces.locales.ILocaleNumbers"""
-        assert category in (u'decimal', u'percent', u'scientific', u'currency')
-        assert length in (u'short', u'medium', u'long', u'full', None)
+        assert category in (_u("decimal"), _u("percent"), _u("scientific"), _u("currency"))
+        assert length in (_u("short"), _u("medium"), _u("long"), _u("full"), None)
 
         formats = getattr(self, category+'Formats')
         if length is None:
             length = getattr(
                 self,
                 'default'+category[0].upper()+category[1:]+'Format',
-                formats.keys()[0])
+                list(formats.keys())[0])
         formatLength = formats[length]
 
         if name is None:
@@ -636,14 +635,14 @@ class LocaleNumbers(AttributeInheritance):
         return NumberFormat(format.pattern, self.symbols)
 
 
+@implementer(ILocaleOrientation)
 class LocaleOrientation(AttributeInheritance):
     """Implementation of ILocaleOrientation
     """
-    implements(ILocaleOrientation)
 
+@implementer(ILocale)
 class Locale(AttributeInheritance):
     """Implementation of the ILocale interface."""
-    implements(ILocale)
 
     def __init__(self, id):
         self.id = id
