@@ -18,6 +18,8 @@ from doctest import DocTestSuite
 from zope.i18n.locales.inheritance import AttributeInheritance
 from zope.i18n.locales.inheritance import NoParentException
 
+from zope.i18n.testing import unicode_checker
+
 class LocaleInheritanceStub(AttributeInheritance):
 
     def __init__(self, nextLocale=None):
@@ -31,9 +33,9 @@ class LocaleInheritanceStub(AttributeInheritance):
 
 def test_suite():
     return unittest.TestSuite((
-        DocTestSuite('zope.i18n.locales'),
-        DocTestSuite('zope.i18n.locales.inheritance'),
-        DocTestSuite('zope.i18n.locales.xmlfactory'),
+        DocTestSuite('zope.i18n.locales', checker=unicode_checker),
+        DocTestSuite('zope.i18n.locales.inheritance', checker=unicode_checker),
+        DocTestSuite('zope.i18n.locales.xmlfactory', checker=unicode_checker),
         ))
 
 if __name__ == '__main__':
