@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2002, 2003 Zope Corporation and Contributors.
+# Copyright (c) 2002, 2003 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,8 +12,6 @@
 #
 ##############################################################################
 """This module tests the Formats and everything that goes with it.
-
-$Id: test_formats.py 88151 2008-07-10 05:57:18Z srichter $
 """
 import decimal
 import os
@@ -31,12 +29,14 @@ from zope.i18n.interfaces import INumberFormat
 from zope.i18n.format import NumberFormat, NumberParseError
 from zope.i18n.format import parseNumberPattern
 
+from .._compat import _u
+
 class LocaleStub(object):
     pass
 
 class LocaleCalendarStub(object):
 
-    type = u'gregorian'
+    type = _u("gregorian")
 
     months = { 1: ('Januar', 'Jan'),     2: ('Februar', 'Feb'),
                3: ('Maerz', 'Mrz'),      4: ('April', 'Apr'),
@@ -173,14 +173,14 @@ class TestDateTimePatternParser(TestCase):
         # Quote not closed
         try:
             parseDateTimePattern("HH' Uhr")
-        except DateTimePatternParseError, err:
+        except DateTimePatternParseError as err:
             self.assertEqual(
                 str(err), 'The quote starting at character 2 is not closed.')
         # Test correct length of characters in datetime fields
         try:
             parseDateTimePattern("HHHHH")
-        except DateTimePatternParseError, err:
-            self.assert_(str(err).endswith('You have: 5'))
+        except DateTimePatternParseError as err:
+            self.assertTrue(str(err).endswith('You have: 5'))
 
 
 class TestBuildDateTimeParseInfo(TestCase):
@@ -224,9 +224,9 @@ class TestBuildDateTimeParseInfo(TestCase):
         self.assertEqual(self.info(('M', 2)), '([0-9]{2})')
 
     def testMonthNames(self):
-        names = [u'Januar', u'Februar', u'Maerz', u'April',
-                 u'Mai', u'Juni', u'Juli', u'August', u'September', u'Oktober',
-                 u'November', u'Dezember']
+        names = [_u("Januar"), _u("Februar"), _u("Maerz"), _u("April"),
+                 _u("Mai"), _u("Juni"), _u("Juli"), _u("August"), _u("September"), _u("Oktober"),
+                 _u("November"), _u("Dezember")]
         self.assertEqual(self.info(('M', 4)), '('+'|'.join(names)+')')
 
     def testMonthAbbr(self):
@@ -257,40 +257,40 @@ class TestDateTimeFormat(TestCase):
     format = DateTimeFormat(calendar=LocaleCalendarStub())
 
     def testInterfaceConformity(self):
-        self.assert_(IDateTimeFormat.providedBy(self.format))
+        self.assertTrue(IDateTimeFormat.providedBy(self.format))
 
     def testParseSimpleDateTime(self):
         # German short
         self.assertEqual(
             self.format.parse('02.01.03 21:48', 'dd.MM.yy HH:mm'),
-            datetime.datetime(2003, 01, 02, 21, 48))
+            datetime.datetime(2003, 1, 2, 21, 48))
 
     def testParseRealDateTime(self):
         # German medium
         self.assertEqual(
             self.format.parse('02.01.2003 21:48:01', 'dd.MM.yyyy HH:mm:ss'),
-            datetime.datetime(2003, 01, 02, 21, 48, 01))
+            datetime.datetime(2003, 1, 2, 21, 48, 1))
 
         # German long
         # TODO: The parser does not support timezones yet.
         self.assertEqual(self.format.parse(
             '2. Januar 2003 21:48:01 +100',
             'd. MMMM yyyy HH:mm:ss z'),
-            datetime.datetime(2003, 01, 02, 21, 48, 01,
-                              tzinfo=pytz.timezone('Europe/Berlin')))
+            pytz.timezone('Europe/Berlin').localize(
+                datetime.datetime(2003, 1, 2, 21, 48, 1)))
 
         # German full
         # TODO: The parser does not support timezones yet.
         self.assertEqual(self.format.parse(
             'Donnerstag, 2. Januar 2003 21:48 Uhr +100',
             "EEEE, d. MMMM yyyy H:mm' Uhr 'z"),
-            datetime.datetime(2003, 01, 02, 21, 48,
-                              tzinfo=pytz.timezone('Europe/Berlin')))
+            pytz.timezone('Europe/Berlin').localize(
+                datetime.datetime(2003, 1, 2, 21, 48)))
 
     def testParseAMPMDateTime(self):
         self.assertEqual(
             self.format.parse('02.01.03 09:48 nachm.', 'dd.MM.yy hh:mm a'),
-            datetime.datetime(2003, 01, 02, 21, 48))
+            datetime.datetime(2003, 1, 2, 21, 48))
 
     def testParseTimeZone(self):
         dt = self.format.parse('09:48 -600', 'HH:mm z')
@@ -322,10 +322,10 @@ class TestDateTimeFormat(TestCase):
         self.assertEqual(dt.tzinfo.zone, 'US/Eastern')
         self.assertEqual(dt.tzinfo.tzname(dt), 'EST')
 
-        dt = self.format.parse('01.01.2003 09:48 Australia/Sydney',
+        dt = self.format.parse('01.01.2003 09:48 Canada/Eastern',
                                'dd.MM.yyyy HH:mm zzzz')
-        self.assertEqual(dt.tzinfo.utcoffset(dt), datetime.timedelta(hours=11))
-        self.assertEqual(dt.tzinfo.zone, 'Australia/Sydney')
+        self.assertEqual(dt.tzinfo.utcoffset(dt), datetime.timedelta(hours=-5))
+        self.assertEqual(dt.tzinfo.zone, 'Canada/Eastern')
         self.assertEqual(dt.tzinfo.tzname(dt), 'EST')
 
         # Note that historical and future (as far as known)
@@ -342,7 +342,6 @@ class TestDateTimeFormat(TestCase):
         self.assertEqual(dt.tzinfo.tzname(dt), 'EDT')
         self.assertEqual(dt.tzinfo.utcoffset(dt), datetime.timedelta(hours=-4))
 
-
     def testDateTimeParseError(self):
         self.assertRaises(DateTimeParseError,
             self.format.parse, '02.01.03 21:48', 'dd.MM.yyyy HH:mm')
@@ -354,28 +353,28 @@ class TestDateTimeFormat(TestCase):
     def testParse12PM(self):
         self.assertEqual(
             self.format.parse('01.01.03 12:00 nachm.', 'dd.MM.yy hh:mm a'),
-            datetime.datetime(2003, 01, 01, 12, 00, 00, 00))
+            datetime.datetime(2003, 1, 1, 12, 00, 00, 00))
 
     def testParseUnusualFormats(self):
         self.assertEqual(
             self.format.parse('001. Januar 03 0012:00',
                               'ddd. MMMMM yy HHHH:mm'),
-            datetime.datetime(2003, 01, 01, 12, 00, 00, 00))
+            datetime.datetime(2003, 1, 1, 12, 00, 00, 00))
         self.assertEqual(
             self.format.parse('0001. Jan 2003 0012:00 vorm.',
                               'dddd. MMM yyyy hhhh:mm a'),
-            datetime.datetime(2003, 01, 01, 00, 00, 00, 00))
+            datetime.datetime(2003, 1, 1, 00, 00, 00, 00))
 
     def testFormatSimpleDateTime(self):
         # German short
         self.assertEqual(
-            self.format.format(datetime.datetime(2003, 01, 02, 21, 48),
+            self.format.format(datetime.datetime(2003, 1, 2, 21, 48),
                               'dd.MM.yy HH:mm'),
             '02.01.03 21:48')
 
     def testFormatRealDateTime(self):
         tz = pytz.timezone('Europe/Berlin')
-        dt = datetime.datetime(2003, 01, 02, 21, 48, 01, tzinfo=tz)
+        dt = tz.localize(datetime.datetime(2003, 1, 2, 21, 48, 1))
         # German medium
         self.assertEqual(
             self.format.format(dt, 'dd.MM.yyyy HH:mm:ss'),
@@ -393,47 +392,47 @@ class TestDateTimeFormat(TestCase):
 
     def testFormatAMPMDateTime(self):
         self.assertEqual(self.format.format(
-            datetime.datetime(2003, 01, 02, 21, 48),
+            datetime.datetime(2003, 1, 2, 21, 48),
             'dd.MM.yy hh:mm a'),
             '02.01.03 09:48 nachm.')
 
     def testFormatAllWeekdays(self):
         for day in range(1, 8):
             self.assertEqual(self.format.format(
-                datetime.datetime(2003, 01, day+5, 21, 48),
+                datetime.datetime(2003, 1, day+5, 21, 48),
                 "EEEE, d. MMMM yyyy H:mm' Uhr 'z"),
                 '%s, %i. Januar 2003 21:48 Uhr +000' %(
                 self.format.calendar.days[day][0], day+5))
 
     def testFormatTimeZone(self):
         self.assertEqual(self.format.format(
-            datetime.datetime(2003, 01, 02, 12, 00), 'z'),
+            datetime.datetime(2003, 1, 2, 12, 00), 'z'),
             '+000')
         self.assertEqual(self.format.format(
-            datetime.datetime(2003, 01, 02, 12, 00), 'zz'),
+            datetime.datetime(2003, 1, 2, 12, 00), 'zz'),
             '+00:00')
         self.assertEqual(self.format.format(
-            datetime.datetime(2003, 01, 02, 12, 00), 'zzz'),
+            datetime.datetime(2003, 1, 2, 12, 00), 'zzz'),
             'UTC')
         self.assertEqual(self.format.format(
-            datetime.datetime(2003, 01, 02, 12, 00), 'zzzz'),
+            datetime.datetime(2003, 1, 2, 12, 00), 'zzzz'),
             'UTC')
         tz = pytz.timezone('US/Eastern')
         self.assertEqual(self.format.format(
-            datetime.datetime(2003, 01, 02, 12, tzinfo=tz), 'z'),
+            tz.localize(datetime.datetime(2003, 1, 2, 12)), 'z'),
             '-500')
         self.assertEqual(self.format.format(
-            datetime.datetime(2003, 01, 02, 12, tzinfo=tz), 'zz'),
+            tz.localize(datetime.datetime(2003, 1, 2, 12)), 'zz'),
             '-05:00')
         self.assertEqual(self.format.format(
-            datetime.datetime(2003, 01, 02, 12, tzinfo=tz), 'zzz'),
+            tz.localize(datetime.datetime(2003, 1, 2, 12)), 'zzz'),
             'EST')
         self.assertEqual(self.format.format(
-            datetime.datetime(2003, 01, 02, 12, tzinfo=tz), 'zzzz'),
+            tz.localize(datetime.datetime(2003, 1, 2, 12)), 'zzzz'),
             'US/Eastern')
 
     def testFormatWeekDay(self):
-        date = datetime.date(2003, 01, 02)
+        date = datetime.date(2003, 1, 2)
         self.assertEqual(self.format.format(date, "E"),
                          '4')
         self.assertEqual(self.format.format(date, "EE"),
@@ -457,7 +456,7 @@ class TestDateTimeFormat(TestCase):
                          '05')
 
     def testFormatDayOfWeekInMonth(self):
-        date = datetime.date(2003, 01, 02)
+        date = datetime.date(2003, 1, 2)
         self.assertEqual(self.format.format(date, "F"),
                          '1')
         self.assertEqual(self.format.format(date, "FF"),
@@ -528,11 +527,11 @@ class TestDateTimeFormat(TestCase):
 
     def testFormatSimpleHourRepresentation(self):
         self.assertEqual(
-            self.format.format(datetime.datetime(2003, 01, 02, 23, 00),
+            self.format.format(datetime.datetime(2003, 1, 2, 23, 00),
                                'dd.MM.yy h:mm:ss a'),
             '02.01.03 11:00:00 nachm.')
         self.assertEqual(
-            self.format.format(datetime.datetime(2003, 01, 02, 02, 00),
+            self.format.format(datetime.datetime(2003, 1, 2, 2, 00),
                                'dd.MM.yy h:mm:ss a'),
             '02.01.03 2:00:00 vorm.')
         self.assertEqual(
@@ -551,54 +550,54 @@ class TestDateTimeFormat(TestCase):
     def testFormatDayInYear(self):
         self.assertEqual(
             self.format.format(datetime.date(2003, 1, 3), 'D'),
-            u'3')
+            _u("3"))
         self.assertEqual(
             self.format.format(datetime.date(2003, 1, 3), 'DD'),
-            u'03')
+            _u("03"))
         self.assertEqual(
             self.format.format(datetime.date(2003, 1, 3), 'DDD'),
-            u'003')
+            _u("003"))
         self.assertEqual(
             self.format.format(datetime.date(2003, 12, 31), 'D'),
-            u'365')
+            _u("365"))
         self.assertEqual(
             self.format.format(datetime.date(2003, 12, 31), 'DD'),
-            u'365')
+            _u("365"))
         self.assertEqual(
             self.format.format(datetime.date(2003, 12, 31), 'DDD'),
-            u'365')
+            _u("365"))
         self.assertEqual(
             self.format.format(datetime.date(2004, 12, 31), 'DDD'),
-            u'366')
+            _u("366"))
 
     def testFormatDayOfWeekInMOnth(self):
         self.assertEqual(
             self.format.format(datetime.date(2003, 1, 3), 'F'),
-            u'1')
+            _u("1"))
         self.assertEqual(
             self.format.format(datetime.date(2003, 1, 10), 'F'),
-            u'2')
+            _u("2"))
         self.assertEqual(
             self.format.format(datetime.date(2003, 1, 17), 'F'),
-            u'3')
+            _u("3"))
         self.assertEqual(
             self.format.format(datetime.date(2003, 1, 24), 'F'),
-            u'4')
+            _u("4"))
         self.assertEqual(
             self.format.format(datetime.date(2003, 1, 31), 'F'),
-            u'5')
+            _u("5"))
         self.assertEqual(
             self.format.format(datetime.date(2003, 1, 6), 'F'),
-            u'1')
+            _u("1"))
 
     def testFormatUnusualFormats(self):
         self.assertEqual(
             self.format.format(datetime.date(2003, 1, 3), 'DDD-yyyy'),
-            u'003-2003')
+            _u("003-2003"))
         self.assertEqual(
             self.format.format(datetime.date(2003, 1, 10),
                                "F. EEEE 'im' MMMM, yyyy"),
-            u'2. Freitag im Januar, 2003')
+            _u("2. Freitag im Januar, 2003"))
 
 
 
@@ -830,7 +829,7 @@ class TestNumberFormat(TestCase):
         'infinity': 'oo', 'nan': 'N/A'})
 
     def testInterfaceConformity(self):
-        self.assert_(INumberFormat.providedBy(self.format))
+        self.assertTrue(INumberFormat.providedBy(self.format))
 
     def testParseSimpleInteger(self):
         self.assertEqual(self.format.parse('23341', '###0'),
